%define _lto_cflags %{nil}
%bcond_without bootstrap

%global groupname jackuser
%global pagroup   pulse-rt

Summary:       Jack Audio Connection Kit
Name:          jack-audio-connection-kit
Version:       1.9.22
Release:       2%{?dist}
License:       GPLv2 and GPLv2+ and LGPLv2+
URL:           https://www.jackaudio.org
Source0:       https://github.com/jackaudio/jack2/archive/v%{version}/v%{version}.tar.gz #/jack2-%{version}.tar.gz
Source1:       %{name}-script.pa
Source2:       %{name}-limits.conf
Patch3001:     jack-realtime-compat.patch

BuildRequires: gcc-c++ pkgconfig python3 doxygen
BuildRequires: dbus-devel expat-devel ncurses-devel alsa-lib-devel
BuildRequires: libsamplerate-devel libsndfile-devel opus-devel
# Berkeley DB v6 new licence (AGPLv3) is incompatible with GPLv2. https://en.wikipedia.org/wiki/Berkeley_DB#Licensing
BuildRequires: libdb-devel < 6.0.20
%if ! %{with bootstrap}
BuildRequires: libffado-devel
%endif

Requires(pre): shadow-utils
Requires:      pam


%description
JACK Audio Connection Kit (or JACK) is a professional sound server API and
pair of daemon implementations to provide real-time, low-latency connections
for both audio and MIDI data between applications.

Jackd is the JACK audio server daemon that allows JACK client programs to process
and route audio and MIDI data in a synchronous, sample-accurate and low-latency manner.
Originally written for the GNU/Linux operating system, it also runs on various Unix
platforms, Mac OS X and MS Windows.

JACK can connect a number of different client applications to an audio device and also
to each other. Most clients are external, running in their own processes as normal applications.
JACK also supports internal clients, which run within the jackd process using a loadable
"plugin" interface.

JACK differs from other audio servers in being designed from the ground up for professional
audio work. It focuses on two key areas: synchronous execution of all clients, and low
latency operation.


%package dbus
Summary:       Jack D-Bus launcher
Requires:      %{name} = %{version}-%{release}

%description dbus
Launcher to start Jack through D-Bus.


%package devel
Summary:       Header files for Jack
Requires:      %{name} = %{version}-%{release}

%description devel
Header files for the Jack Audio Connection Kit.


%package example-clients
Summary:       Example clients that use Jack 

%description example-clients
Small example clients that use the Jack Audio Connection Kit.


%prep
%autosetup -p1 -n jack2-%{version}


%build
export PREFIX=%{_prefix}
python3 ./waf configure \
   --mandir=%{_mandir}/man1 \
   --libdir=%{_libdir} \
   --doxygen \
   --dbus \
   --db \
   --classic \
%if ! %{with bootstrap}
   --firewire \
%endif
   --alsa \
   --clients 256 \
   --ports-per-application=2048

python3 ./waf build %{?_smp_mflags} -v


%install
python3 ./waf --destdir=%{buildroot} install

mv %{buildroot}%{_datadir}/jack-audio-connection-kit/reference .
rm -rf %{buildroot}%{_datadir}/jack-audio-connection-kit

install -p -m644 %{SOURCE1} jack.pa

mkdir -p %{buildroot}%{_sysconfdir}/security/limits.d
sed -e 's,@groupname@,%groupname,g; s,@pagroup@,%pagroup,g;' \
    %{SOURCE2} > %{buildroot}%{_sysconfdir}/security/limits.d/95-jack.conf

chmod 755 %{buildroot}%{_libdir}/jack/*.so %{buildroot}%{_libdir}/libjack*.so.*.*.*


%pre
getent group %groupname > /dev/null || groupadd -r %groupname
exit 0


%files
%license COPYING
%doc ChangeLog.rst README.rst README_NETJACK2
%doc jack.pa
%config(noreplace) %{_sysconfdir}/security/limits.d/*.conf
%{_bindir}/jackd
%{_libdir}/jack/
%{_libdir}/libjack.so.0*
%{_libdir}/libjacknet.so.0*
%{_libdir}/libjackserver.so.0*
%{_mandir}/man1/jackd*.1*


%files dbus
%{_bindir}/jackdbus
%{_bindir}/jack_control
%{_datadir}/dbus-1/services/org.jackaudio.service


%files devel
%doc reference/html/
%{_includedir}/jack/
%{_libdir}/libjack.so
%{_libdir}/libjacknet.so
%{_libdir}/libjackserver.so
%{_libdir}/pkgconfig/jack.pc


%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.9.22-2
- Rebuilt for OpenCloudOS Stream 23.05

* Wed Apr 19 2023 rockerzhu <rockerzhu@tencent.com> - 1.9.22-1
- Initial build.
